var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * @memberof components
 * @namespace Accordion
 * @author Steven Jackson
 * @scss ../../scss/components/Accordion
 * @example <Accordion>
   <Accordion.Title>
     Example Title
   </Accordion.Title>
   <Accordion.Content>
     Example Content
   </Accordion.Content>
 </Accordion>
 */
import React, { cloneElement } from "react";
import { CoreComponent, getValidProps, setCorePropTypes, setPropDefaultsAutoId, ROLE } from "../../lib";
import AccordionTitle from "./AccordionTitle.js";
import AccordionContent from "./AccordionContent.js";
import "./Accordion.css";

var Accordion = (_temp = _class = function (_CoreComponent) {
  _inherits(Accordion, _CoreComponent);

  function Accordion(props) {
    _classCallCheck(this, Accordion);

    var _this = _possibleConstructorReturn(this, _CoreComponent.call(this, props));

    _initialiseProps.call(_this);

    _this.maxIndex = -1;
    _this.state = {
      activeItem: props.id + "_item_0"
    };
    return _this;
  }

  return Accordion;
}(CoreComponent), _class.propTypes = setCorePropTypes({
  caret: "bool"
}), _class.defaultProps = setPropDefaultsAutoId({
  renderAs: "dl",
  uirole: ROLE.ACCORDION,
  caret: false
}), _class.Title = AccordionTitle, _class.Content = AccordionContent, _initialiseProps = function _initialiseProps() {
  var _this2 = this;

  this.getTitleIndex = function () {
    _this2.maxIndex = _this2.maxIndex + 1;
    return _this2.maxIndex;
  };

  this.getContentIndex = function () {
    return _this2.maxIndex;
  };

  this.handleOnClick = function (e) {
    e.preventDefault();
    e.stopPropagation();
    var accordionindex = e.currentTarget.attributes.accordionindex;

    var activeItem = accordionindex.value;
    if (activeItem === _this2.state.activeItem) {
      _this2.setState({ activeItem: "" });
    } else {
      _this2.setState({ activeItem: activeItem });
    }
  };

  this.renderChild = function (child, props, parentId, getIndex) {
    var role = child.props.uirole;
    var index = getIndex();
    var activeItem = parentId + "_item_" + index;
    var ref = function ref(c) {
      _this2[activeItem] = c;
    };
    if (typeof child.ref !== "string") {
      ref = _this2.chainFunction(child.ref, ref);
    }
    return cloneElement(child, _this2.setChildProps(role, ref, _extends({}, props, {
      accordionindex: activeItem,
      active: activeItem === _this2.state.activeItem
    })));
  };

  this.renderCore = function () {
    var _getValidProps = getValidProps(_this2.props),
        Component = _getValidProps.renderAs,
        id = _getValidProps.id,
        caret = _getValidProps.caret,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    _this2.maxIndex = -1;

    return React.createElement(
      Component,
      props,
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
          switch (child.props.uirole) {
            case ROLE.TITLE:
              return _this2.renderChild(child, _extends({}, inherited, {
                caret: caret,
                onClick: _this2.handleOnClick
              }), id, _this2.getTitleIndex);
            case ROLE.CONTENT:
              return _this2.renderChild(child, _extends({}, inherited, {
                caret: caret
              }), id, _this2.getContentIndex);
            default:
              return child;
          }
        }
        return child;
      })
    );
  };
}, _temp);


export default Accordion;